@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2016 - 2018 Kopano b.v.
- * SPDX-FileCopyrightText: Copyright 2020 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * A wrapper for Monolog Logger.
  */
@@ -15,6 +15,8 @@ use Monolog\Handler\ErrorLogHandler;
 use Monolog\Handler\NullHandler;
 use Monolog\Handler\StreamHandler;
 use Monolog\Processor\ProcessIdProcessor;
+use Sabre\HTTP\RequestInterface;
+use Sabre\HTTP\ResponseInterface;
 
 /**
  * GLogger: wraps the monolog Logger.
@@ -40,7 +42,7 @@ class GLogger {
 		}
 
 		// let GLogger handle error messages
-		set_error_handler('\\grommunio\\DAV\\GLogger::ErrorHandler');
+		set_error_handler('\grommunio\DAV\GLogger::ErrorHandler');
 	}
 
 	/**
@@ -99,20 +101,17 @@ class GLogger {
 		// Log messages formatting
 		$lineFormat = null;
 
-		if (isset($configuration['lineFormat']) &&
-			is_string($configuration['lineFormat'])) {
+		if (isset($configuration['lineFormat']) && is_string($configuration['lineFormat'])) {
 			$lineFormat = stripcslashes($configuration['lineFormat']);
 		} // stripcslashes to recognize "\n"
 
 		$timeFormat = null;
 
-		if (isset($configuration['timeFormat']) &&
-			is_string($configuration['timeFormat'])) {
+		if (isset($configuration['timeFormat']) && is_string($configuration['timeFormat'])) {
 			$timeFormat = $configuration['timeFormat'];
 		}
 
-		if ($lineFormat ||
-			$timeFormat) {
+		if ($lineFormat || $timeFormat) {
 			$formatter = new LineFormatter($lineFormat, $timeFormat, true, true);
 			$stream->setFormatter($formatter);
 		}
@@ -141,8 +140,7 @@ class GLogger {
 	/**
 	 * Returns a GLogger by name. If it does not exist, it will be created.
 	 *
-	 * @param string $name  The logger name
-	 * @param mixed  $class
+	 * @param mixed $class
 	 *
 	 * @return Logger
 	 */
@@ -172,7 +170,7 @@ class GLogger {
 	/**
 	 * Logs the incoming data (headers + body) to debug.
 	 */
-	public function LogIncoming(\Sabre\HTTP\RequestInterface $request) {
+	public function LogIncoming(RequestInterface $request) {
 		// only do any of this is we are looking for debug messages
 		if ($this->logger->isHandling(Logger::DEBUG)) {
 			$inputHeader = $request->getMethod() . ' ' . $request->getUrl() . ' HTTP/' . $request->getHTTPVersion() . "\r\n";
@@ -202,7 +200,7 @@ class GLogger {
 	/**
 	 * Logs the outgoing data (headers + body) to debug.
 	 */
-	public function LogOutgoing(\Sabre\HTTP\ResponseInterface $response) {
+	public function LogOutgoing(ResponseInterface $response) {
 		// only do any of this is we are looking for debug messages
 		if ($this->logger->isHandling(Logger::DEBUG)) {
 			$output = 'HTTP/' . $response->getHttpVersion() . ' ' . $response->getStatus() . ' ' . $response->getStatusText() . "\n";
@@ -260,14 +258,28 @@ class GLogger {
 		$t = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, 3);
 
 		if ($count == 0) {
-			$this->logger->error(sprintf("No arguments in %s->%s() logging to '%s' in %s:%d", static::GetClassnameOnly($t[2]['class']), $t[2]['function'], $t[1]['function'], $t[1]['file'], $t[1]['line']));
+			$this->logger->error(sprintf(
+				"No arguments in %s->%s() logging to '%s' in %s:%d",
+				static::GetClassnameOnly($t[2]['class']),
+				$t[2]['function'],
+				$t[1]['function'],
+				$t[1]['file'],
+				$t[1]['line']
+			));
 
 			return false;
 		}
 		// Only check formatting if there are format parameters. Otherwise there will be
 		// an error log if the $arguments[0] contain %-chars.
 		if (($count > 1) && ((substr_count($arguments[0], "%") - $quoted_procent * 2) !== $count - 1)) {
-			$this->logger->error(sprintf("Wrong number of arguments in %s->%s() logging to '%s' in %s:%d", static::GetClassnameOnly($t[2]['class']), $t[2]['function'], $t[1]['function'], $t[1]['file'], $t[1]['line']));
+			$this->logger->error(sprintf(
+				"Wrong number of arguments in %s->%s() logging to '%s' in %s:%d",
+				static::GetClassnameOnly($t[2]['class']),
+				$t[2]['function'],
+				$t[1]['function'],
+				$t[1]['file'],
+				$t[1]['line']
+			));
 
 			return false;
 		}
@@ -329,10 +341,10 @@ class GLogger {
 	 */
 	public static function ErrorHandler($errno, $errstr, $errfile, $errline, $errcontext = []) {
 		if (defined('LOG_ERROR_MASK')) {
-			$errno &= LOG_ERROR_MASK;
+			$errno &= \LOG_ERROR_MASK;
 		}
 
-		$logger = self::$parentLogger ?? new GLogger('error');
+		$logger = new GLogger('error');
 
 		switch ($errno) {
 			case 0:
@@ -345,7 +357,7 @@ class GLogger {
 
 			case E_NOTICE:
 			case E_WARNING:
-				$logger->warn("{$errfile}:{$errline} {$errstr} ({$errno})");
+				$logger->warning("{$errfile}:{$errline} {$errstr} ({$errno})");
 				break;
 
 			default:
@@ -371,16 +383,13 @@ class GLogger {
 	 * if the loglevel is activated.
 	 *
 	 * @param mixed $message message
-	 * @param mixed ...params
 	 */
-	public function trace() {
-		if (DEVELOPER_MODE) {
-			if (!$this->verifyLogSyntax(func_get_args())) {
-				return;
-			}
+	public function trace(...$message) {
+		if (DEVELOPER_MODE && !$this->verifyLogSyntax($message)) {
+			return;
 		}
 		if ($this->logger->isHandling(Logger::TRACE)) {
-			$this->writeLog(Logger::TRACE, func_get_args());
+			$this->writeLog(Logger::TRACE, $message);
 		}
 	}
 
@@ -390,16 +399,13 @@ class GLogger {
 	 * if the loglevel is activated.
 	 *
 	 * @param mixed $message message
-	 * @param mixed ...params
 	 */
-	public function debug() {
-		if (DEVELOPER_MODE) {
-			if (!$this->verifyLogSyntax(func_get_args())) {
-				return;
-			}
+	public function debug(...$message) {
+		if (DEVELOPER_MODE && !$this->verifyLogSyntax($message)) {
+			return;
 		}
 		if ($this->logger->isHandling(Logger::DEBUG)) {
-			$this->writeLog(Logger::DEBUG, func_get_args());
+			$this->writeLog(Logger::DEBUG, $message);
 		}
 	}
 
@@ -409,16 +415,13 @@ class GLogger {
 	 * if the loglevel is activated.
 	 *
 	 * @param mixed $message message
-	 * @param mixed ...params
 	 */
-	public function info() {
-		if (DEVELOPER_MODE) {
-			if (!$this->verifyLogSyntax(func_get_args())) {
-				return;
-			}
+	public function info(...$message) {
+		if (DEVELOPER_MODE && !$this->verifyLogSyntax($message)) {
+			return;
 		}
 		if ($this->logger->isHandling(Logger::INFO)) {
-			$this->writeLog(Logger::INFO, func_get_args());
+			$this->writeLog(Logger::INFO, $message);
 		}
 	}
 
@@ -428,16 +431,13 @@ class GLogger {
 	 * if the loglevel is activated.
 	 *
 	 * @param mixed $message message
-	 * @param mixed ...params
 	 */
-	public function warn() {
-		if (DEVELOPER_MODE) {
-			if (!$this->verifyLogSyntax(func_get_args())) {
-				return;
-			}
+	public function warn(...$message) {
+		if (DEVELOPER_MODE && !$this->verifyLogSyntax($message)) {
+			return;
 		}
 		if ($this->logger->isHandling(Logger::WARNING)) {
-			$this->writeLog(Logger::WARNING, func_get_args(), ' - ' . $this->getCaller(1, true));
+			$this->writeLog(Logger::WARNING, $message, ' - ' . $this->getCaller(1, true));
 		}
 	}
 
@@ -447,16 +447,13 @@ class GLogger {
 	 * if the loglevel is activated.
 	 *
 	 * @param mixed $message message
-	 * @param mixed ...params
 	 */
-	public function error() {
-		if (DEVELOPER_MODE) {
-			if (!$this->verifyLogSyntax(func_get_args())) {
-				return;
-			}
+	public function error(...$message) {
+		if (DEVELOPER_MODE && !$this->verifyLogSyntax($message)) {
+			return;
 		}
 		if ($this->logger->isHandling(Logger::ERROR)) {
-			$this->writeLog(Logger::ERROR, func_get_args(), ' - ' . $this->getCaller(1, true));
+			$this->writeLog(Logger::ERROR, $message, ' - ' . $this->getCaller(1, true));
 		}
 	}
 
@@ -466,16 +463,13 @@ class GLogger {
 	 * if the loglevel is activated.
 	 *
 	 * @param mixed $message message
-	 * @param mixed ...params
 	 */
-	public function fatal() {
-		if (DEVELOPER_MODE) {
-			if (!$this->verifyLogSyntax(func_get_args())) {
-				return;
-			}
+	public function fatal(...$message) {
+		if (DEVELOPER_MODE && !$this->verifyLogSyntax($message)) {
+			return;
 		}
 		if ($this->logger->isHandling(Logger::CRITICAL)) {
-			$this->writeLog(Logger::CRITICAL, func_get_args(), ' - ' . $this->getCaller(1, true));
+			$this->writeLog(Logger::CRITICAL, $message, ' - ' . $this->getCaller(1, true));
 		}
 	}
 }
