@@ -191,7 +191,6 @@ class GrommunioCalDavBackend extends AbstractBackend implements SchedulingSuppor
 		$start = $end = null;
 		$types = [];
 		foreach ($filters['comp-filters'] as $filter) {
-			$this->logger->trace("got filter: %s", $filter);
 
 			if ($filter['name'] == 'VEVENT') {
 				$types[] = 'IPM.Appointment';
@@ -271,7 +270,6 @@ class GrommunioCalDavBackend extends AbstractBackend implements SchedulingSuppor
 			$this->logger->error("Error generating ical, unknown error");
 			$ics = null;
 		}
-		$this->logger->trace("ics generated by mapi_mapitoical: %s%s", PHP_EOL, $ics);
 
 		$props = mapi_getprops($mapimessage, [PR_LAST_MODIFICATION_TIME]);
 
@@ -309,7 +307,7 @@ class GrommunioCalDavBackend extends AbstractBackend implements SchedulingSuppor
 	 * @return null|string
 	 */
 	public function createCalendarObject($calendarId, $objectUri, $calendarData) {
-		$this->logger->trace("calendarId: %s - objectUri: %s - calendarData: %s", $calendarId, $objectUri, $calendarData);
+		$this->logger->trace("calendarId: %s - objectUri: %s", $calendarId, $objectUri);
 		$objectId = $this->gDavBackend->GetObjectIdFromObjectUri($objectUri, static::FILE_EXTENSION);
 		$folder = $this->gDavBackend->GetMapiFolder($calendarId);
 		$mapimessage = $this->gDavBackend->CreateObject($calendarId, $folder, $objectId);
@@ -341,7 +339,7 @@ class GrommunioCalDavBackend extends AbstractBackend implements SchedulingSuppor
 	 * @return null|string
 	 */
 	public function updateCalendarObject($calendarId, $objectUri, $calendarData) {
-		$this->logger->trace("calendarId: %s - objectUri: %s - calendarData: %s", $calendarId, $objectUri, $calendarData);
+		$this->logger->trace("calendarId: %s - objectUri: %s", $calendarId, $objectUri);
 
 		$folder = $this->gDavBackend->GetMapiFolder($calendarId);
 		$mapimessage = $this->gDavBackend->GetMapiMessageForId($calendarId, $objectUri, null, static::FILE_EXTENSION);
@@ -363,7 +361,6 @@ class GrommunioCalDavBackend extends AbstractBackend implements SchedulingSuppor
 	 * @return null|string
 	 */
 	private function setData($calendarId, $mapimessage, $ics) {
-		$this->logger->trace("mapimessage: %s - ics: %s", $mapimessage, $ics);
 		// this should be cached or moved to gDavBackend
 		$store = $this->gDavBackend->GetStoreById($calendarId);
 		$session = $this->gDavBackend->GetSession();
